NAME
Paws::Route53Domains::RenewDomainResponse
ATTRIBUTES
REQUIRED OperationId => Str
The identifier for tracking the progress of the request. To use this ID to query the operation status, use GetOperationDetail.
Paws::Route53Domains::RenewDomainResponse
The identifier for tracking the progress of the request. To use this ID to query the operation status, use GetOperationDetail.